Re: [PD] got jump-on-click arrays working

2013-05-04 Thread Jonathan Wilkes
Hi List,
 More "Put" menu array fun:

* settable colors for the trace + "jump on click" action

http://puredata.info/Members/jancsika/array-in-color/view

* bar graph with settable outline/fill colors
http://puredata.info/Members/jancsika/bargraph-array/view

* resizing bar graph
http://puredata.info/Members/jancsika/bargraph-sinesum/view

* multiple colored arrays in one graph
http://puredata.info/Members/jancsika/two-arrays/view

plus:

* savable colors for "Put" menu arrays

* html-style color symbols savable in last two args to [plot]


Please test.  Data structure "bargraph" arrays probably look a little
screwy-- haven't worked on those yet.

-Jonathan
diff -rupN pd-0.43-0-old/src/g_array.c pd-0.43-0/src/g_array.c
--- pd-0.43-0-old/src/g_array.c	2013-05-01 01:48:51.225292121 -0400
+++ pd-0.43-0/src/g_array.c	2013-05-04 22:39:40.503151248 -0400
@@ -132,16 +132,19 @@ struct _garray
 t_symbol *x_realname;   /* expanded name (symbol we're bound to) */
 char x_usedindsp;   /* true if some DSP routine is using this */
 char x_saveit;  /* true if we should save this with parent */
+char x_joc; /* true if we should "jump on click" in a graph */
 char x_listviewing; /* true if list view window is open */
 char x_hidename;/* don't print name above graph */
+t_symbol *x_fillcolor;   /* color for filled area of the are */
+t_symbol *x_outlinecolor;/* color of the outline around the element */
 };
 
 static t_pd *garray_arraytemplatecanvas;
 static char garray_arraytemplatefile[] = "\
 #N canvas 0 0 458 153 10;\n\
 #X obj 43 31 struct _float_array array z float float style\n\
-float linewidth float color;\n\
-#X obj 43 70 plot z color linewidth 0 0 1 style;\n\
+float linewidth float color symbol fillcolor symbol outlinecolor;\n\
+#X obj 43 70 plot z color linewidth 0 0 1 style fillcolor outlinecolor;\n\
 ";
 static char garray_floattemplatefile[] = "\
 #N canvas 0 0 458 153 10;\n\
@@ -179,7 +182,7 @@ always called by graph_array() below; bu
 to save and create arrays this might get called more directly. */
 
 static t_garray *graph_scalar(t_glist *gl, t_symbol *s, t_symbol *templatesym,
-int saveit)
+t_symbol *fill, t_symbol *outline, int saveit)
 {
 int i, zz;
 t_garray *x;
@@ -187,8 +190,8 @@ static t_garray *graph_scalar(t_glist *g
 t_template *template;
 char *str;
 t_gpointer gp;
-if (!template_findbyname(templatesym))
-return (0);  
+if (!(template = template_findbyname(templatesym)))
+return (0);
 x = (t_garray *)pd_new(garray_class);
 x->x_scalar = scalar_new(gl, templatesym);
 x->x_name = s;
@@ -197,6 +200,10 @@ static t_garray *graph_scalar(t_glist *g
 x->x_usedindsp = 0;
 x->x_saveit = saveit;
 x->x_listviewing = 0;
+template_setsymbol(template, gensym("fillcolor"), x->x_scalar->sc_vec,
+fill, 1);
+template_setsymbol(template, gensym("outlinecolor"), x->x_scalar->sc_vec,
+outline, 1);
 glist_add(gl, &x->x_gobj);
 x->x_glist = gl;
 return (x);
@@ -252,6 +259,11 @@ int garray_getname(t_garray *x, t_symbol
 *namep = x->x_name;
 return (x->x_hidename);
 }
+/* find out if array elements should "jump on click" in a graph */
+int garray_joc(t_garray *x)
+{
+return (x->x_joc);
+}
 
 /* if there is one garray in a graph, reset the graph's coordinates
 to fit a new size and style for the garray */
@@ -263,8 +275,8 @@ static void garray_fittograph(t_garray *
 {
 vmess(&gl->gl_pd, gensym("bounds"), "",
 0., gl->gl_y1, (double)
-(style == PLOTSTYLE_POINTS || n == 1 ? n : n-1),
-gl->gl_y2);
+(style == PLOTSTYLE_POINTS || style == PLOTSTYLE_BARS
+|| n == 1 ? n : n-1), gl->gl_y2);
 /* close any dialogs that might have the wrong info now... */
 gfxstub_deleteforkey(gl);
 }
@@ -276,10 +288,21 @@ an appropriate template; then set size a
 from the menu and in the file format for patches.  LATER replace this
 by a more coherent (and general) invocation. */
 
-t_garray *graph_array(t_glist *gl, t_symbol *s, t_symbol *templateargsym,
-t_floatarg fsize, t_floatarg fflags)
+t_garray *graph_array(t_glist *gl, t_symbol *s, int argc, t_atom *argv)
 {
-int n = fsize, i, zz, nwords, zonset, ztype, saveit;
+t_symbol *fill;
+t_symbol *outline;
+
+if (argc < 4) {pd_error(gl, "arraydialog: not enough args"); return 0;}
+t_symbol *name = atom_getsymbolarg(0, argc--, argv++);
+int fsize = (int)atom_getfloatarg(0, argc--, argv++);
+t_symbol *templateargsym = atom_getsymbolarg(0, argc--, argv++);
+int fflags = (int)atom_getfloatarg(0, argc--, argv++);
+if (argc) fill = atom_getsymbolarg(0, argc--, argv++);
+else fill = gensym("black");
+if (argc) outline = atom_getsymbolarg(0, argc--, argv++);
+else outline = gensym("black");
+int n = fsize

[PD] [PD-announce] Ringtone - Amplitude Modulation Sequencer in Pd

2013-05-04 Thread Alexandre Torres Porres
Hi there, I'm releasing a simple vanilla patch.

I stole the idea from http://www.youtube.com/watch?v=LT5-yXaLpwA

Here's the patch, which does more stuff...
https://sites.google.com/site/porres/ringtone.zip

I got more ideas that I wanna implement later, as well as some
enhancements. But this is enough fun for you and all your family.

I'd love to see you try it on your raspberry Pis. I don't have my around
just now, but I think it's a light patch that will run smoothly on it.

Cheers
___
Pd-announce mailing list
pd-annou...@iem.at
http://lists.puredata.info/listinfo/pd-announce
___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list


Re: [PD] Cheap audio USB device with Raspberry PI -- works!

2013-05-04 Thread Alexandre Torres Porres
Yeah, Deal Extreme, Great, Free Shipping to Brazil :)

2013/4/30 me.grimm 

> That's without dwc_otg.speed=1 added to /boot/cmdline.txt 
>
> *m*
>
> On Apr 30, 2013, at 5:08 PM, Julian Brooks  wrote:
>
> Blimey:)
>
> Could be really useful for workshops etc.
> £1.81 and free shipping to U.K (takes a while tho', so plan ahead).
> Nice find.
>
> Julian
>
>
> On 30 April 2013 21:54, Max  wrote:
>
>> i've added this info to
>> https://puredata.info/docs/raspberry-pi/FrontPage
>> it has no vendor/brand name, but the model is: HY544
>>
>> Am 30.04.2013 um 22:14 schrieb Alexandre Castonguay <
>> acastong...@artengine.ca>:
>>
>> > Hi all,
>> >
>> > This card works (audio i/o) with the Raspberry PI (Raspbian).
>> >
>> > You just need to type 'amixer -c 1 set Mic 80% cap' in a term window to
>> > enable to Mic.  In PD, under preferences, choose 'Alsa' as output and
>> > under 'audio configuration', select 'input Generic AudioUSB Device
>> > (hardware) Channels 1' and 'output Generic USB Audio Device (plug-in)
>> > Channels 2'.
>> >
>> > This is the beast :-) ->
>> >
>> > http://dx.com/p/usb-3d-sound-adapter-color-assorted-5831  (2.80 USD!)
>> >
>> > Have fun,
>> >
>> > * Merci à André Girard!
>> >
>> > Alexandre
>> >
>> > ___
>> > Pd-list@iem.at mailing list
>> > UNSUBSCRIBE and account-management ->
>> http://lists.puredata.info/listinfo/pd-list
>>
>>
>> ___
>> Pd-list@iem.at mailing list
>> UNSUBSCRIBE and account-management ->
>> http://lists.puredata.info/listinfo/pd-list
>>
>
> ___
> Pd-list@iem.at mailing list
> UNSUBSCRIBE and account-management ->
> http://lists.puredata.info/listinfo/pd-list
>
>
> ___
> Pd-list@iem.at mailing list
> UNSUBSCRIBE and account-management ->
> http://lists.puredata.info/listinfo/pd-list
>
>
___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list


[PD] Ringtone - Amplitude Modulation Sequencer in Pd

2013-05-04 Thread Alexandre Torres Porres
Hi there, I'm releasing a simple vanilla patch.

I stole the idea from http://www.youtube.com/watch?v=LT5-yXaLpwA

Here's the patch, which does more stuff...
https://sites.google.com/site/porres/ringtone.zip

I got more ideas that I wanna implement later, as well as some
enhancements. But this is enough fun for you and all your family.

I'd love to see you try it on your raspberry Pis. I don't have my around
just now, but I think it's a light patch that will run smoothly on it.

Cheers
___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list


[PD] RPI Alsa mmap support

2013-05-04 Thread Julian Brooks
Hi all,

Dunno if everyone's on this already but looks useful:
http://martinezjavier.wordpress.com/2013/04/27/mmap-support-for-raspberry-pi-bcm2835-alsa-driver/

>From here:
http://www.raspberrypi.org/phpBB3/viewtopic.php?f=38&t=33462&p=334943#p334943

Not tested as of yet but anything that squeezes a bit more audio
performance out of the RPi is to be welcomed.

rpi-update ahoy,

Julian
___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list


Re: [PD] UA-25 on RPI

2013-05-04 Thread Martin Peach

On 2013-05-04 12:50, Dan Wilcox wrote:

No thanks. The UA-25 is bus powered, has two XLR+jack inputs, phantom
power, rca/jack outputs, direct monitor, individual channel gain
control, master gain control, and in a road tuff metal case. I have two
of them, so it makes sense to dump the PI if I can't get it to work with
proven linux friendly hardware especially when the pi costs less.

Too bad. Back to iPad now ... :D


Maybe a beaglebone black:
http://beagleboard.org/Products/BeagleBone%20Black

I have a Behringer UCA202 running on a beaglebone with no problems.

Martin


___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list


Re: [PD] UA-25 on RPI

2013-05-04 Thread Dan Wilcox
No thanks. The UA-25 is bus powered, has two XLR+jack inputs, phantom power, 
rca/jack outputs, direct monitor, individual channel gain control, master gain 
control, and in a road tuff metal case. I have two of them, so it makes sense 
to dump the PI if I can't get it to work with proven linux friendly hardware 
especially when the pi costs less.

Too bad. Back to iPad now ... :D
 
On May 4, 2013, at 12:42 PM, Antoine Villeret  
wrote:

> ok bad news...
> 
> what about using another sound card ?
> UGM6 has 2 hi-Z input (but without no phantom) and 2 outputs
> it may fit your needs
> 
> +
> a
> 
> --
> do it yourself   
> http://antoine.villeret.free.fr
> 
> 
> 2013/5/4 Dan Wilcox 
> Yes. Ethernet turbo disabled and Ethernet disabled. Disabled cpu freq 
> scaling. Pd set with realtime permissions:
> 
> sudo chmod 4755 /usr/bin/pd-extended
> sudo chmod 4755 /usr/bin/pd
> 
> Setting dwc_otg.speed=1 dosen't work for this card and yields an unstable 
> system.
> 
> This is pretty disappointing as my old setup was on an embedded 500Mhz 
> Celeron with half the RAM and almost no video memory, yet (so far) was 
> running Pd + alsa better than the superiorly specced PI. The main reason I'm 
> not using the wearable anymore is it's just worn out and trying to fix 
> flexxed pcbs and the resultant random glitches was getting old years ago.
> 
> On May 4, 2013, at 12:31 PM, Antoine Villeret  
> wrote:
> 
>> Hi dan, 
>> 
>> Did you try to disable Ethernet turbo or to disable Ethernet at all as 
>> describe on linuxaudio.org [1] ?
>> it gives me good result with ESI sound card (UGM-6, see my post on the list 
>> from Thursday).
>> 
>> Cheers
>> 
>> a
>> [1] http://wiki.linuxaudio.org/wiki/raspberrypi
>> 
>> --
>> do it yourself   
>> http://antoine.villeret.free.fr
>> 
>> 
>> 2013/5/4 Dan Wilcox 
>> For what it's worth, output did work using: 
>> 
>> pd-extended -nogui -noadc -audiooutdev 3 test.pd
>> 
>> with 3 being the direct alsa interface as opposed to the alsa plug interface.
>> 
>> It's when I enable the audioindev that I get crackles. I know there are 
>> people out there using the UA-25 + jack, but I never needed jack before with 
>> an embedded setup.
>> 
>> Part of the issue might be the RPI's real-time kernel. My old wearable setup 
>> was far more unstable with a realtime kernel and using a regular kernel with 
>> realtime permissions for PD worked far better.
>> 
>> On May 4, 2013, at 11:52 AM, Miller Puckette  wrote:
>> 
>>> HI Dan -
>>> 
>>> I tried and got even less far than you apparently did, and gave up.  It's 
>>> too
>>> bad - the UA 25 is the best USB-powered interface I've found so far.  For 
>>> the
>>> Pi I now use small, cheap, recent-vintage ones like the Griffin iMic. (but
>>> there are even cheaper ones :)  If you have low-impedance mics, my best
>>> guess would be to use an impedance matching transformer (lo to hi) and then
>>> a "PC mic" (high impedance) interface.
>>> 
>>> cheers
>>> M
>>> 
>>> On Sat, May 04, 2013 at 10:57:35AM -0400, Dan Wilcox wrote:
 Howdy everyone,
 
 Anyone had luck with a Roland/Edirol UA-25 with PD on a RaspberryPi? I've 
 gotten it working fine with output, but enabling input gives me crackles 
 and bad cpu usage. Ideally, I want 2 in / 2 out and this audio interface 
 has worked wonderfully with Linux on older/slower machines in the past. 
 The RPI should have no problem spec-wise to run this with PD using only 
 alsa ...
 
 
 Dan Wilcox
 @danomatika
 danomatika.com
 robotcowboy.com
 
 
 
 
 
>>> 
 ___
 Pd-list@iem.at mailing list
 UNSUBSCRIBE and account-management -> 
 http://lists.puredata.info/listinfo/pd-list
>>> 
>> 
>> 
>> Dan Wilcox
>> @danomatika
>> danomatika.com
>> robotcowboy.com
>> 
>> 
>> 
>> 
>> 
>> 
>> ___
>> Pd-list@iem.at mailing list
>> UNSUBSCRIBE and account-management -> 
>> http://lists.puredata.info/listinfo/pd-list
>> 
>> 
> 
> 
> Dan Wilcox
> @danomatika
> danomatika.com
> robotcowboy.com
> 
> 
> 
> 
> 
> 


Dan Wilcox
@danomatika
danomatika.com
robotcowboy.com





___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list


Re: [PD] UA-25 on RPI

2013-05-04 Thread Antoine Villeret
ok bad news...

what about using another sound card ?
UGM6 has 2 hi-Z input (but without no phantom) and 2 outputs
it may fit your needs

+
a

--
do it yourself
http://antoine.villeret.free.fr


2013/5/4 Dan Wilcox 

> Yes. Ethernet turbo disabled and Ethernet disabled. Disabled cpu freq
> scaling. Pd set with realtime permissions:
>
> sudo chmod 4755 /usr/bin/pd-extended
> sudo chmod 4755 /usr/bin/pd
>
> Setting dwc_otg.speed=1 dosen't work for this card and yields an unstable
> system.
>
> This is pretty disappointing as my old setup was on an embedded 500Mhz
> Celeron with half the RAM and almost no video memory, yet (so far) was
> running Pd + alsa better than the superiorly specced PI. The main reason
> I'm not using the wearable anymore is it's just worn out and trying to fix
> flexxed pcbs and the resultant random glitches was getting old years ago.
>
> On May 4, 2013, at 12:31 PM, Antoine Villeret 
> wrote:
>
> Hi dan,
>
> Did you try to disable Ethernet turbo or to disable Ethernet at all
> as describe on linuxaudio.org [1] ?
> it gives me good result with ESI sound card (UGM-6, see my post on the
> list from Thursday).
>
> Cheers
>
> a
> [1] http://wiki.linuxaudio.org/wiki/raspberrypi
>
> --
> do it yourself
> http://antoine.villeret.free.fr
>
>
> 2013/5/4 Dan Wilcox 
>
>> For what it's worth, output did work using:
>>
>> pd-extended -nogui -noadc -audiooutdev 3 test.pd
>>
>> with 3 being the direct alsa interface as opposed to the alsa plug
>> interface.
>>
>> It's when I enable the audioindev that I get crackles. I know there are
>> people out there using the UA-25 + jack, but I never needed jack before
>> with an embedded setup.
>>
>> Part of the issue might be the RPI's real-time kernel. My old wearable
>> setup was far more unstable with a realtime kernel and using a regular
>> kernel with realtime permissions for PD worked far better.
>>
>> On May 4, 2013, at 11:52 AM, Miller Puckette  wrote:
>>
>> HI Dan -
>>
>> I tried and got even less far than you apparently did, and gave up.  It's
>> too
>> bad - the UA 25 is the best USB-powered interface I've found so far.  For
>> the
>> Pi I now use small, cheap, recent-vintage ones like the Griffin iMic. (but
>> there are even cheaper ones :)  If you have low-impedance mics, my best
>> guess would be to use an impedance matching transformer (lo to hi) and
>> then
>> a "PC mic" (high impedance) interface.
>>
>> cheers
>> M
>>
>> On Sat, May 04, 2013 at 10:57:35AM -0400, Dan Wilcox wrote:
>>
>> Howdy everyone,
>>
>> Anyone had luck with a Roland/Edirol UA-25 with PD on a RaspberryPi? I've
>> gotten it working fine with output, but enabling input gives me crackles
>> and bad cpu usage. Ideally, I want 2 in / 2 out and this audio interface
>> has worked wonderfully with Linux on older/slower machines in the past. The
>> RPI should have no problem spec-wise to run this with PD using only alsa ...
>>
>> 
>> Dan Wilcox
>> @danomatika
>> danomatika.com
>> robotcowboy.com
>>
>>
>>
>>
>>
>>
>> ___
>> Pd-list@iem.at mailing list
>> UNSUBSCRIBE and account-management ->
>> http://lists.puredata.info/listinfo/pd-list
>>
>>
>>
>>  
>> Dan Wilcox
>> @danomatika
>> danomatika.com
>> robotcowboy.com
>>
>>
>>
>>
>>
>>
>> ___
>> Pd-list@iem.at mailing list
>> UNSUBSCRIBE and account-management ->
>> http://lists.puredata.info/listinfo/pd-list
>>
>>
>
>  
> Dan Wilcox
> @danomatika
> danomatika.com
> robotcowboy.com
>
>
>
>
>
>
___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list


Re: [PD] UA-25 on RPI

2013-05-04 Thread Dan Wilcox
Yes. Ethernet turbo disabled and Ethernet disabled. Disabled cpu freq scaling. 
Pd set with realtime permissions:

sudo chmod 4755 /usr/bin/pd-extended
sudo chmod 4755 /usr/bin/pd

Setting dwc_otg.speed=1 dosen't work for this card and yields an unstable 
system.

This is pretty disappointing as my old setup was on an embedded 500Mhz Celeron 
with half the RAM and almost no video memory, yet (so far) was running Pd + 
alsa better than the superiorly specced PI. The main reason I'm not using the 
wearable anymore is it's just worn out and trying to fix flexxed pcbs and the 
resultant random glitches was getting old years ago.

On May 4, 2013, at 12:31 PM, Antoine Villeret  
wrote:

> Hi dan, 
> 
> Did you try to disable Ethernet turbo or to disable Ethernet at all as 
> describe on linuxaudio.org [1] ?
> it gives me good result with ESI sound card (UGM-6, see my post on the list 
> from Thursday).
> 
> Cheers
> 
> a
> [1] http://wiki.linuxaudio.org/wiki/raspberrypi
> 
> --
> do it yourself   
> http://antoine.villeret.free.fr
> 
> 
> 2013/5/4 Dan Wilcox 
> For what it's worth, output did work using: 
> 
> pd-extended -nogui -noadc -audiooutdev 3 test.pd
> 
> with 3 being the direct alsa interface as opposed to the alsa plug interface.
> 
> It's when I enable the audioindev that I get crackles. I know there are 
> people out there using the UA-25 + jack, but I never needed jack before with 
> an embedded setup.
> 
> Part of the issue might be the RPI's real-time kernel. My old wearable setup 
> was far more unstable with a realtime kernel and using a regular kernel with 
> realtime permissions for PD worked far better.
> 
> On May 4, 2013, at 11:52 AM, Miller Puckette  wrote:
> 
>> HI Dan -
>> 
>> I tried and got even less far than you apparently did, and gave up.  It's too
>> bad - the UA 25 is the best USB-powered interface I've found so far.  For the
>> Pi I now use small, cheap, recent-vintage ones like the Griffin iMic. (but
>> there are even cheaper ones :)  If you have low-impedance mics, my best
>> guess would be to use an impedance matching transformer (lo to hi) and then
>> a "PC mic" (high impedance) interface.
>> 
>> cheers
>> M
>> 
>> On Sat, May 04, 2013 at 10:57:35AM -0400, Dan Wilcox wrote:
>>> Howdy everyone,
>>> 
>>> Anyone had luck with a Roland/Edirol UA-25 with PD on a RaspberryPi? I've 
>>> gotten it working fine with output, but enabling input gives me crackles 
>>> and bad cpu usage. Ideally, I want 2 in / 2 out and this audio interface 
>>> has worked wonderfully with Linux on older/slower machines in the past. The 
>>> RPI should have no problem spec-wise to run this with PD using only alsa ...
>>> 
>>> 
>>> Dan Wilcox
>>> @danomatika
>>> danomatika.com
>>> robotcowboy.com
>>> 
>>> 
>>> 
>>> 
>>> 
>> 
>>> ___
>>> Pd-list@iem.at mailing list
>>> UNSUBSCRIBE and account-management -> 
>>> http://lists.puredata.info/listinfo/pd-list
>> 
> 
> 
> Dan Wilcox
> @danomatika
> danomatika.com
> robotcowboy.com
> 
> 
> 
> 
> 
> 
> ___
> Pd-list@iem.at mailing list
> UNSUBSCRIBE and account-management -> 
> http://lists.puredata.info/listinfo/pd-list
> 
> 


Dan Wilcox
@danomatika
danomatika.com
robotcowboy.com





___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list


Re: [PD] UA-25 on RPI

2013-05-04 Thread Antoine Villeret
Hi dan,

Did you try to disable Ethernet turbo or to disable Ethernet at all
as describe on linuxaudio.org [1] ?
it gives me good result with ESI sound card (UGM-6, see my post on the list
from Thursday).

Cheers

a
[1] http://wiki.linuxaudio.org/wiki/raspberrypi

--
do it yourself
http://antoine.villeret.free.fr


2013/5/4 Dan Wilcox 

> For what it's worth, output did work using:
>
> pd-extended -nogui -noadc -audiooutdev 3 test.pd
>
> with 3 being the direct alsa interface as opposed to the alsa plug
> interface.
>
> It's when I enable the audioindev that I get crackles. I know there are
> people out there using the UA-25 + jack, but I never needed jack before
> with an embedded setup.
>
> Part of the issue might be the RPI's real-time kernel. My old wearable
> setup was far more unstable with a realtime kernel and using a regular
> kernel with realtime permissions for PD worked far better.
>
> On May 4, 2013, at 11:52 AM, Miller Puckette  wrote:
>
> HI Dan -
>
> I tried and got even less far than you apparently did, and gave up.  It's
> too
> bad - the UA 25 is the best USB-powered interface I've found so far.  For
> the
> Pi I now use small, cheap, recent-vintage ones like the Griffin iMic. (but
> there are even cheaper ones :)  If you have low-impedance mics, my best
> guess would be to use an impedance matching transformer (lo to hi) and then
> a "PC mic" (high impedance) interface.
>
> cheers
> M
>
> On Sat, May 04, 2013 at 10:57:35AM -0400, Dan Wilcox wrote:
>
> Howdy everyone,
>
> Anyone had luck with a Roland/Edirol UA-25 with PD on a RaspberryPi? I've
> gotten it working fine with output, but enabling input gives me crackles
> and bad cpu usage. Ideally, I want 2 in / 2 out and this audio interface
> has worked wonderfully with Linux on older/slower machines in the past. The
> RPI should have no problem spec-wise to run this with PD using only alsa ...
>
> 
> Dan Wilcox
> @danomatika
> danomatika.com
> robotcowboy.com
>
>
>
>
>
>
> ___
> Pd-list@iem.at mailing list
> UNSUBSCRIBE and account-management ->
> http://lists.puredata.info/listinfo/pd-list
>
>
>
>  
> Dan Wilcox
> @danomatika
> danomatika.com
> robotcowboy.com
>
>
>
>
>
>
> ___
> Pd-list@iem.at mailing list
> UNSUBSCRIBE and account-management ->
> http://lists.puredata.info/listinfo/pd-list
>
>
___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list


Re: [PD] UA-25 on RPI

2013-05-04 Thread Dan Wilcox
For what it's worth, output did work using: 

pd-extended -nogui -noadc -audiooutdev 3 test.pd

with 3 being the direct alsa interface as opposed to the alsa plug interface.

It's when I enable the audioindev that I get crackles. I know there are people 
out there using the UA-25 + jack, but I never needed jack before with an 
embedded setup.

Part of the issue might be the RPI's real-time kernel. My old wearable setup 
was far more unstable with a realtime kernel and using a regular kernel with 
realtime permissions for PD worked far better.

On May 4, 2013, at 11:52 AM, Miller Puckette  wrote:

> HI Dan -
> 
> I tried and got even less far than you apparently did, and gave up.  It's too
> bad - the UA 25 is the best USB-powered interface I've found so far.  For the
> Pi I now use small, cheap, recent-vintage ones like the Griffin iMic. (but
> there are even cheaper ones :)  If you have low-impedance mics, my best
> guess would be to use an impedance matching transformer (lo to hi) and then
> a "PC mic" (high impedance) interface.
> 
> cheers
> M
> 
> On Sat, May 04, 2013 at 10:57:35AM -0400, Dan Wilcox wrote:
>> Howdy everyone,
>> 
>> Anyone had luck with a Roland/Edirol UA-25 with PD on a RaspberryPi? I've 
>> gotten it working fine with output, but enabling input gives me crackles and 
>> bad cpu usage. Ideally, I want 2 in / 2 out and this audio interface has 
>> worked wonderfully with Linux on older/slower machines in the past. The RPI 
>> should have no problem spec-wise to run this with PD using only alsa ...
>> 
>> 
>> Dan Wilcox
>> @danomatika
>> danomatika.com
>> robotcowboy.com
>> 
>> 
>> 
>> 
>> 
> 
>> ___
>> Pd-list@iem.at mailing list
>> UNSUBSCRIBE and account-management -> 
>> http://lists.puredata.info/listinfo/pd-list
> 


Dan Wilcox
@danomatika
danomatika.com
robotcowboy.com





___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list


Re: [PD] UA-25 on RPI

2013-05-04 Thread Miller Puckette
HI Dan -

I tried and got even less far than you apparently did, and gave up.  It's too
bad - the UA 25 is the best USB-powered interface I've found so far.  For the
Pi I now use small, cheap, recent-vintage ones like the Griffin iMic. (but
there are even cheaper ones :)  If you have low-impedance mics, my best
guess would be to use an impedance matching transformer (lo to hi) and then
a "PC mic" (high impedance) interface.

cheers
M

On Sat, May 04, 2013 at 10:57:35AM -0400, Dan Wilcox wrote:
> Howdy everyone,
> 
> Anyone had luck with a Roland/Edirol UA-25 with PD on a RaspberryPi? I've 
> gotten it working fine with output, but enabling input gives me crackles and 
> bad cpu usage. Ideally, I want 2 in / 2 out and this audio interface has 
> worked wonderfully with Linux on older/slower machines in the past. The RPI 
> should have no problem spec-wise to run this with PD using only alsa ...
> 
> 
> Dan Wilcox
> @danomatika
> danomatika.com
> robotcowboy.com
> 
> 
> 
> 
> 

> ___
> Pd-list@iem.at mailing list
> UNSUBSCRIBE and account-management -> 
> http://lists.puredata.info/listinfo/pd-list


___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list


[PD] UA-25 on RPI

2013-05-04 Thread Dan Wilcox
Howdy everyone,

Anyone had luck with a Roland/Edirol UA-25 with PD on a RaspberryPi? I've 
gotten it working fine with output, but enabling input gives me crackles and 
bad cpu usage. Ideally, I want 2 in / 2 out and this audio interface has worked 
wonderfully with Linux on older/slower machines in the past. The RPI should 
have no problem spec-wise to run this with PD using only alsa ...


Dan Wilcox
@danomatika
danomatika.com
robotcowboy.com





___
Pd-list@iem.at mailing list
UNSUBSCRIBE and account-management -> 
http://lists.puredata.info/listinfo/pd-list